==> eisp-mdm-3.6.1.release-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTermCustPostDao_findTermCustPostList.sql <==
SELECT distinct tc.id,
	tc.business_group businessGroup,
	tp.id positionId,
	tp.position_name positionName,
	term.id terminalId,
	term.terminal_code terminalCode,
	term.terminal_name terminalName,
	u.fullname fullName,
	u.mobilephone mobilephone,
	term.terminal_type terminalType,
	cust.id custId,
	cust.customer_name customerName,
	tr.org_name businessGroupOrgName,
	tr.id businessGroupOrgId,
	tc.ext_char_1 bgExtChar1,
	tc.ext_char_2 bgExtChar2,
	tc.deliver,
	tc.remark,
	(SELECT  GROUP_CONCAT(detail_code SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelCode,
    (SELECT   GROUP_CONCAT(detail_name SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelName,
    (SELECT GROUP_CONCAT(detail_code SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productCode,
    (SELECT GROUP_CONCAT(detail_name SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productName,
    (SELECT GROUP_CONCAT(detail_code SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaCode,
    (SELECT GROUP_CONCAT(detail_name SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaName
FROM TM_R_TERM_CUST_POS_BG tc
LEFT JOIN TM_POSITION tp ON tp.ID=tc.position_id 
left join tm_r_user_position up on up.position_id=tc.position_id
left join tm_user u on u.id=up.user_id
LEFT JOIN TM_TERMINAL  term ON term.ID=tc.TERMINAL_ID
LEFT JOIN TM_CUSTOMER cust ON cust.ID=tc.CUSTOMER_ID
LEFT JOIN TM_ORG tr ON tr.ID=tc.ORG_ID
WHERE 1=1
<#if tmTermCustPostVo.positionId ?exists&&tmTermCustPostVo.positionId ?length gt 0>
	AND tc.POSITION_ID = '${tmTermCustPostVo.positionId}'
</#if> 
<#if tmTermCustPostVo.terminalCode ?exists&&tmTermCustPostVo.terminalCode ?length gt 0>
	AND term.TERMINAL_CODE LIKE '%${tmTermCustPostVo.terminalCode}%'
</#if> 
<#if tmTermCustPostVo.terminalName ?exists&&tmTermCustPostVo.terminalName ?length gt 0>
	AND term.TERMINAL_NAME LIKE '%${tmTermCustPostVo.terminalName}%'
</#if> 
<#if tmTermCustPostVo.terminalType ?exists&&tmTermCustPostVo.terminalType ?length gt 0>
	AND term.TERMINAL_TYPE = '${tmTermCustPostVo.terminalType}'
</#if> 
<#if tmTermCustPostVo.customerId ?exists&&tmTermCustPostVo.customerId ?length gt 0>
	AND tc.CUSTOMER_ID = '${tmTermCustPostVo.customerId}'
</#if> 
<#if tmTermCustPostVo.terminalId ?exists&&tmTermCustPostVo.terminalId ?length gt 0>
	AND tc.TERMINAL_ID = '${tmTermCustPostVo.terminalId}'
</#if>

==> eisp-mdm-3.8.2.release-classes.jar: com/biz/eisp/mdm/terminal/sql/TmTermCustPostDao_findTermCustPostList.sql <==
SELECT distinct tc.id,
	tc.business_group businessGroup,
	tp.id positionId,
	tp.position_name positionName,
	term.id terminalId,
	term.terminal_code terminalCode,
	term.terminal_name terminalName,
	term.province,
	term.city,
	term.area,
	u.fullname fullName,
	u.mobilephone mobilephone,
	term.terminal_type terminalType,
	cust.id custId,
	cust.customer_name customerName,
	tr.org_name businessGroupOrgName,
	tr.org_name,
	tco.cust_org_name,
	tr.id businessGroupOrgId,
	tc.ext_char_1 bgExtChar1,
	tc.ext_char_2 bgExtChar2,
	tc.deliver,
	tc.remark,
	(SELECT  GROUP_CONCAT(detail_code SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelCode,
    (SELECT   GROUP_CONCAT(detail_name SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'channelCode' AND d.business_group = tc.business_group) AS channelName,
    (SELECT GROUP_CONCAT(detail_code SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productCode,
    (SELECT GROUP_CONCAT(detail_name SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'productCode' AND d.business_group = tc.business_group) AS productName,
    (SELECT GROUP_CONCAT(detail_code SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaCode,
    (SELECT GROUP_CONCAT(detail_name SEPARATOR ';')
                 FROM tm_r_term_cust_pos_bg_detail d WHERE d.type_code = 'businessAreaCode' AND d.business_group = tc.business_group) AS businessAreaName
FROM TM_R_TERM_CUST_POS_BG tc
JOIN TM_TERMINAL  term ON term.ID=tc.TERMINAL_ID
LEFT JOIN TM_POSITION tp ON tp.ID=tc.position_id 
left join tm_r_user_position up on up.position_id=tc.position_id
left join tm_user u on u.id=up.user_id
LEFT JOIN TM_CUSTOMER_ORG  tco ON tco.ID=term.customer_org_id
LEFT JOIN TM_CUSTOMER cust ON cust.ID=tc.CUSTOMER_ID
LEFT JOIN TM_ORG tr ON tr.ID=term.ORG_ID
WHERE 1=1
<#if tmTermCustPostVo.positionId ?exists&&tmTermCustPostVo.positionId ?length gt 0>
	AND tc.POSITION_ID = '${tmTermCustPostVo.positionId}'
</#if> 
<#if tmTermCustPostVo.terminalCode ?exists&&tmTermCustPostVo.terminalCode ?length gt 0>
	AND term.TERMINAL_CODE LIKE '%${tmTermCustPostVo.terminalCode}%'
</#if> 
<#if tmTermCustPostVo.terminalName ?exists&&tmTermCustPostVo.terminalName ?length gt 0>
	AND term.TERMINAL_NAME LIKE '%${tmTermCustPostVo.terminalName}%'
</#if> 
<#if tmTermCustPostVo.terminalType ?exists&&tmTermCustPostVo.terminalType ?length gt 0>
	AND term.TERMINAL_TYPE = '${tmTermCustPostVo.terminalType}'
</#if> 
<#if tmTermCustPostVo.customerId ?exists&&tmTermCustPostVo.customerId ?length gt 0>
	AND tc.CUSTOMER_ID = '${tmTermCustPostVo.customerId}'
</#if> 
<#if tmTermCustPostVo.terminalId ?exists&&tmTermCustPostVo.terminalId ?length gt 0>
	AND tc.TERMINAL_ID = '${tmTermCustPostVo.terminalId}'
</#if>
<#if tmTermCustPostVo.custOrgName ?exists&&tmTermCustPostVo.custOrgName ?length gt 0>
	AND tco.CUST_ORG_NAME LIKE '%${tmTermCustPostVo.custOrgName}%'
</#if>
<#if tmTermCustPostVo.orgName ?exists&&tmTermCustPostVo.orgName ?length gt 0>
	AND tr.org_name LIKE '%${tmTermCustPostVo.orgName}%'
</#if>
